@@ -5,8 +5,10 @@ from django.utils.functional import classproperty
 
 from aleksis.apps.untis.util.mysql.importers.terms import (
     get_future_terms_for_date,
+    get_future_terms_for_date_query,
     get_terms,
     get_terms_for_date,
+    get_terms_for_date_query,
 )
 
 from .util.mysql.main import untis_import_mysql as _untis_import_mysql
@@ -28,7 +30,12 @@ class ImportCommand:
         return None
 
     @classmethod
-    def run(cls, background: bool = False, version: Optional[int] = None):
+    def run(
+        cls,
+        background: bool = False,
+        school_id: Optional[int] = None,
+        version: Optional[int] = None,
+    ):
         """Run the import command (foreground/background)."""
         if background:
             from .tasks import TASKS
@@ -36,7 +43,7 @@ class ImportCommand:
             task = TASKS[cls.task_name]
             task.delay(version=version)
         else:
-            _untis_import_mysql(cls.get_terms(), version=version)
+            _untis_import_mysql(cls.get_terms(), school_id=school_id, version=version)
 
 
 class CurrentImportCommand(ImportCommand):
@@ -70,16 +77,20 @@ class CurrentNextImportCommand(ImportCommand):
 
     @classmethod
     def get_terms(cls) -> Optional[QuerySet]:
-        terms = get_terms_for_date()
         future_terms = get_future_terms_for_date()
         if future_terms.exists():
             future_term = future_terms.first()
-            terms = (
-                get_terms()
-                .filter(Q(pk__in=terms.values_list("pk", flat=True)) | Q(pk=future_term.pk))
-                .distinct()
+            return get_terms().filter(
+                get_terms_for_date_query()
+                | Q(
+                    school_id=future_term.school_id,
+                    schoolyear_id=future_term.schoolyear_id,
+                    version_id=future_term.version_id,
+                    term_id=future_term.term_id,
+                )
             )
-        return terms
+        else:
+            return get_terms_for_date()
 
 
 class CurrentFutureImportCommand(ImportCommand):
@@ -89,16 +100,7 @@ class CurrentFutureImportCommand(ImportCommand):
 
     @classmethod
     def get_terms(cls) -> Optional[QuerySet]:
-        terms = get_terms_for_date()
-        future_terms = get_future_terms_for_date()
-        terms = (
-            get_terms()
-            .filter(
-                Q(pk__in=terms.values_list("pk", flat=True))
-                | Q(pk__in=future_terms.values_list("pk", flat=True))
-            )
-            .distinct()
-        )
+        terms = get_terms().filter(get_future_terms_for_date_query() | get_terms_for_date_query())
         return terms
 
 
