@@ -6,7 +6,7 @@ from ...commands import COMMANDS_BY_NAME
 class Command(BaseCommand):
     def add_arguments(self, parser):
         parser.add_argument(
-            "command", nargs="?", default="all", type=str, choices=list(COMMANDS_BY_NAME.keys())
+            "command", nargs="?", default="current", type=str, choices=list(COMMANDS_BY_NAME.keys())
         )
         parser.add_argument(
             "--background",
@@ -17,9 +17,14 @@ class Command(BaseCommand):
             "--plan-version",
             help="Select explicit Untis plan version",
         )
+        parser.add_argument(
+            "--school-id",
+            help="Select explicit Untis school ID",
+        )
 
     def handle(self, *args, **options):
         command = COMMANDS_BY_NAME[options["command"]]
         background = options["background"]
+        school_id = options.get("school_id", None)
         version = options.get("plan_version", None)
         command.run(background=background, version=version)
