@@ -13,9 +13,10 @@ def guess_school_id(apps, schema_editor):
     except ValidityRange.DoesNotExist:
         return
 
-    school_id = vr.school_id_untis
-    if school_id:
-        get_site_preferences()["untis_mysql__school_id"] = school_id
+    if not vr or not vr.school_id_untis:
+        return
+
+    get_site_preferences()["untis_mysql__school_id"] = school_id
 
 
 class Migration(migrations.Migration):
