@@ -1,10 +1,12 @@
 import logging
+from datetime import timedelta
 from enum import Enum
 
+from calendarweek import CalendarWeek
 from tqdm import tqdm
 
 from aleksis.apps.chronos import models as chronos_models
-from aleksis.apps.chronos.models import ValidityRange
+from aleksis.apps.chronos.models import TimePeriod, ValidityRange
 
 from .... import models as mysql_models
 from ..util import (
@@ -40,6 +42,8 @@ def import_absences(
     untis_term_start = date_to_untis_date(validity_range.date_start)
     untis_term_end = date_to_untis_date(validity_range.date_end)
 
+    created_substitutions = []
+
     # Get absences
     absences = (
         run_default_filter(validity_range, mysql_models.Absence.objects, filter_term=False)
@@ -142,6 +146,36 @@ def import_absences(
         existing_absences.append(import_ref)
         ref[import_ref] = new_absence
 
+        if group:
+            # If a group is absent, all lessons of this group are cancelled.
+            current_date = date_from
+            while current_date <= date_to:
+                current_period_from = (
+                    period_from if current_date == date_from else TimePeriod.period_min
+                )
+                current_period_to = period_to if current_date == date_to else TimePeriod.period_max
+
+                lesson_periods = (
+                    chronos_models.LessonPeriod.objects.filter_group(group)
+                    .on_day(current_date)
+                    .filter(
+                        period__period__gte=current_period_from,
+                        period__period__lte=current_period_to,
+                    )
+                )
+
+                for lesson_period in lesson_periods:
+                    week = CalendarWeek.from_date(current_date)
+                    sub, __ = chronos_models.LessonSubstitution.objects.get_or_create(
+                        lesson_period=lesson_period,
+                        week=week.week,
+                        year=week.year,
+                        defaults=dict(cancelled=True, absence_ref_untis=import_ref),
+                    )
+                    created_substitutions.append(sub)
+
+                current_date += timedelta(days=1)
+
     # Delete all no longer existing absences
     for a in chronos_models.Absence.objects.filter(
         date_start__lte=validity_range.date_end, date_end__gte=validity_range.date_start
@@ -149,5 +183,6 @@ def import_absences(
         if a.import_ref_untis and a.import_ref_untis not in existing_absences:
             logger.info("Absence {} deleted".format(a.id))
             a.delete()
+            LessonSubstitution.objects.filter(absence_ref_untis=a.import_ref_untis).delete()
 
-    return ref
+    return ref, created_substitutions
