@@ -8,6 +8,7 @@ from tqdm import tqdm
 
 from aleksis.apps.chronos import models as chronos_models
 from aleksis.apps.chronos.models import ValidityRange
+from aleksis.core.util.core_helpers import get_site_preferences
 
 from .... import models as mysql_models
 from ..util import (
@@ -34,8 +35,13 @@ def import_substitutions(
     classes_ref,
     supervision_areas_ref,
     time_periods_ref,
+    absence_substitutions=None,
 ):
     """Import substitutions."""
+    if not absence_substitutions:
+        absence_substitutions = []
+    absence_substitutions = [sub.absence_ref_untis for sub in absence_substitutions]
+
     subs = (
         run_default_filter(validity_range, mysql_models.Substitution.objects, filter_term=False)
         .filter(
@@ -138,6 +144,18 @@ def import_substitutions(
             for id_ in class_ids:
                 classes.append(classes_ref[id_])
 
+            if get_site_preferences()["untis_mysql__ignore_incomplete_substitutions"]:
+                # Skip incomplete substitutions
+                if (
+                    not room_new
+                    and not subject_new
+                    and not teachers
+                    and not cancelled
+                    and not cancelled_for_teachers
+                    and not comment
+                ):
+                    continue
+
             if lesson_period:
                 (substitution, created,) = chronos_models.LessonSubstitution.objects.get_or_create(
                     lesson_period=lesson_period, week=week.week, year=week.year
@@ -246,7 +264,9 @@ def import_substitutions(
         validity_range.date_start, validity_range.date_end
     )
     for s in lesson_substitutions_in_range:
-        if s.import_ref_untis and s.import_ref_untis not in existing_subs:
+        if (s.import_ref_untis and s.import_ref_untis not in existing_subs) or (
+            s.absence_ref_untis and s.absence_ref_untis not in absence_substitutions
+        ):
             logger.info("Substitution {} deleted".format(s.id))
             s.delete()
 
