@@ -2,7 +2,7 @@ import logging
 from datetime import date
 from typing import Dict, Optional
 
-from django.db.models import Max, OuterRef, QuerySet, Subquery
+from django.db.models import Max, OuterRef, Q, QuerySet, Subquery
 from django.utils import timezone
 
 from tqdm import tqdm
@@ -15,6 +15,7 @@ from aleksis.apps.untis.util.mysql.util import (
     untis_date_to_date,
 )
 from aleksis.core import models as core_models
+from aleksis.core.util.core_helpers import get_site_preferences
 
 from .... import models as mysql_models
 
@@ -24,27 +25,32 @@ def get_terms() -> QuerySet:
     return run_using(mysql_models.Terms.objects).order_by("datefrom")
 
 
-def get_terms_for_date(for_date: Optional[date] = None) -> QuerySet:
-    """Get term queryset with term valid for the provided date."""
+def get_terms_for_date_query(for_date: Optional[date] = None) -> QuerySet:
+    """Get term query object with term valid for the provided date."""
     if not for_date:
         for_date = timezone.now().date()
 
-    qs = get_terms().filter(
-        datefrom__lte=date_to_untis_date(for_date),
-        dateto__gte=date_to_untis_date(for_date),
-    )
+    return Q(datefrom__lte=date_to_untis_date(for_date), dateto__gte=date_to_untis_date(for_date))
+
+
+def get_terms_for_date(for_date: Optional[date] = None) -> QuerySet:
+    """Get term queryset with term valid for the provided date."""
+    qs = get_terms().filter(get_terms_for_date_query(for_date))
 
     return qs
 
 
-def get_future_terms_for_date(for_date: Optional[date] = None) -> QuerySet:
-    """Get all furture terms (after the current term)."""
+def get_future_terms_for_date_query(for_date: Optional[date] = None) -> QuerySet:
+    """Get term query object with all future terms."""
     if not for_date:
         for_date = timezone.now().date()
 
-    qs = get_terms().filter(
-        datefrom__gt=date_to_untis_date(for_date),
-    )
+    return Q(datefrom__gt=date_to_untis_date(for_date))
+
+
+def get_future_terms_for_date(for_date: Optional[date] = None) -> QuerySet:
+    """Get all future terms (after the current term)."""
+    qs = get_terms().filter(get_future_terms_for_date_query(for_date))
 
     return qs
 
@@ -54,6 +60,7 @@ logger = logging.getLogger(__name__)
 
 def import_terms(
     qs: Optional[QuerySet] = None,
+    school_id: Optional[int] = None,
     version: Optional[int] = None,
 ) -> Dict[int, chronos_models.ValidityRange]:
     """Import terms and school years as validity ranges and school terms."""
@@ -62,6 +69,10 @@ def import_terms(
     if not isinstance(qs, QuerySet):
         qs = run_using(mysql_models.Terms.objects)
 
+    if school_id is None:
+        school_id = get_site_preferences()["untis_mysql__school_id"]
+    qs = qs.filter(school_id=school_id)
+
     if version is None:
         # Select newest version per term / validity range
         sub_qs = (
