@@ -5,6 +5,7 @@ from django.db.models import QuerySet
 import reversion
 from tqdm import tqdm
 
+from aleksis.apps.chronos.util.change_tracker import TimetableDataChangeTracker
 from aleksis.apps.untis.util.mysql.importers.terms import import_terms
 from aleksis.apps.untis.util.mysql.util import TQDM_DEFAULTS
 
@@ -20,14 +21,17 @@ from .importers.common_data import (
     import_time_periods,
 )
 from .importers.events import import_events
+from .importers.exams import import_exams
 from .importers.holidays import import_holidays
 from .importers.lessons import import_lessons
 from .importers.substitutions import import_substitutions
 
 
-def untis_import_mysql(terms: Optional[QuerySet] = None, version: Optional[int] = None):
+def untis_import_mysql(
+    terms: Optional[QuerySet] = None, school_id: Optional[int] = None, version: Optional[int] = None
+):
     # School terms and validity ranges
-    validity_ref = import_terms(terms, version=version)
+    validity_ref = import_terms(terms, school_id=school_id, version=version)
 
     for validity_range in tqdm(
         validity_ref.values(), desc="Import data for terms", **TQDM_DEFAULTS
@@ -35,6 +39,8 @@ def untis_import_mysql(terms: Optional[QuerySet] = None, version: Optional[int]
         with reversion.create_revision(atomic=True):
             reversion.set_comment(f"Untis import for validity range {validity_range}")
 
+            tracker = TimetableDataChangeTracker()
+
             # Common data for Chronos
             subjects_ref = import_subjects(validity_range)
             rooms_ref = import_rooms(validity_range)
@@ -67,7 +73,7 @@ def untis_import_mysql(terms: Optional[QuerySet] = None, version: Optional[int]
             )
 
             # Substitutions
-            import_absences(
+            __, created_substitutions = import_absences(
                 validity_range,
                 absence_reasons_ref,
                 time_periods_ref,
@@ -83,7 +89,11 @@ def untis_import_mysql(terms: Optional[QuerySet] = None, version: Optional[int]
                 classes_ref,
                 supervision_areas_ref,
                 time_periods_ref,
+                created_substitutions,
             )
 
             # Events
             import_events(validity_range, time_periods_ref, teachers_ref, classes_ref, rooms_ref)
+
+            # Exams
+            import_exams(validity_range, time_periods_ref, subjects_ref, teachers_ref, rooms_ref)
